#!/bin/sh
#
# ## Plugin for Nagios to monitor PROGRESS 
# ## Written by Mariusz Dziewulski
# ##
#
# ## You are free to use this script under the terms of the Gnu Public License.
# ## No guarantee - use at your own risc.
#
# Usage: ./check_progress_dbread.sh -pf pf-file
#
# ## Description:
#
# This plugin determines performance of PROGRESS database 
#
# ## Output:
#
# The plugin prints the performance parameter of database
# 
# Exit Codes
# 0 OK       
# 1 Warning  
# 2 Critical 
# 3 Unknown 
#
# Example: check_progress_dbread.sh -pf dbpf.pf
#

PROGNAME=`/usr/bin/basename $0`
PROGPATH=`echo $0 | /bin/sed -e 's,[\\/][^\\/][^\\/]*$,,'`
. $PROGPATH/config.dlc

REVISION="Revision 1.0"
AUTHOR="(c) 2005 Mariusz Dziewulski" 

# Exit codes                                                                                                                                
STATE_OK=0                                                                                                                                  
STATE_WARNING=1                                                                                                                             
STATE_CRITICAL=2                                                                                                                            
STATE_UNKNOWN=3                                                                                                                             
STATE_DEPENDENT=4 


print_revision() {                                                                                                                          
    echo "$REVISION $AUTHOR"                                                                                                                
}                                                                                                                                           
                                                                                                                                            
print_usage() {                                                                                                                             
    echo "Usage: $PROGNAME -pf pf-file"                                                                                   
    echo "Usage: $PROGNAME --help"                                                                                                          
    echo "Usage: $PROGNAME --version"                                                                                                       
}                                                                                                                                           
                                                                                                                                            
print_help() {                                                                                                                              
    print_revision $PROGNAME $REVISION                                                                                                      
    echo ""                                                                                                                                 
    echo "Performance monitoring of PROGRESS database"                                                                                         
    echo ""                                                                                                                                 
    print_usage                                                                                                                             
    echo ""                                                                                                                                 
} 


# Make sure the correct number of command line                                                                                              
# arguments have been supplied                                                                                                              
                                                                                                                                            
if [ $# -lt 2 ]; then                                                                                                                       
    print_usage                                                                                                                             
    exit $STATE_UNKNOWN                                                                                                                     
fi 

exitstatus=$STATE_WARNING #default
while test -n "$1"; do
    case "$1" in
        --help)
            print_help
            exit $STATE_OK
            ;;
        -h)
            print_help
            exit $STATE_OK
            ;;
        --version)
            print_revision $PROGNAME $VERSION
            exit $STATE_OK
            ;;
        -V)
            print_revision $PROGNAME $VERSION
            exit $STATE_OK
            ;;
	-pf)
	    pf_file=$2
	    shift
            ;;
        *)                                                                                                                                  
            echo "Unknown argument: $1"                                                                                                     
            print_usage                                                                                                                     
            exit $STATE_UNKNOWN                                                                                                             
            ;;                                                                                                                              
    esac                                                                                                                                    
    shift                                                                                                                                   
done 

if [ -f $pf_file ]
then 
    $DLC/bin/_progres -b -pf $pf_file -p $PROGPATH/p_actsummary.p
else
    echo "PF file do not exist"
    exitstatus=$STATE_UNKNOWN
    exit $exitstatus   
fi

ss=`cat $tempfile`
rm -f $tempfile
c1=`echo $ss | cut -f1 -d'|'`
    
c2=`echo $ss | cut -f2 -d'|' | tr -d " " | tr -d "."`                                                                                                                             
c3=`echo $ss | cut -f3 -d'|' | tr -d " " | tr -d "."`                                                                                                                             
c4=`echo $ss | cut -f4 -d'|' | tr -d " " | tr -d "."`                                                                                                                             
c5=`echo $ss | cut -f5 -d'|' | tr -d " " | tr -d "."`                                                                                                                             
c6=`echo $ss | cut -f6 -d'|' | tr -d " " | tr -d "."`                                                                                                                             
c7=`echo $ss | cut -f7 -d'|' | tr -d " " | tr -d "."`                                                                                                                             
c8=`echo $ss | cut -f8 -d'|' | tr -d " " | tr -d "."` 

exitstatus=$STATE_OK
echo $c1" | "$c2"rec/s "$c3"rec/s "$c4"rec/s "$c5"rec/s "$c6"rec/s "$c7" "$c8 
exit $exitstatus
